>From bb0c427db8259619441157876c00124711693fdc Mon Sep 17 00:00:00 2001
From: Tadas Slotkus <devtadas@gmail.com>
Date: Wed, 17 Aug 2011 14:14:57 +0300
Subject: [carFl mem 14/21] Move coreboot specific variables to globals

lb_part, lb_vendor, partvendor_from_cbtable

Signed-off-by: Tadas Slotkus <devtadas@gmail.com>
---
 board_enable.c |    2 +-
 cbtable.c      |   21 +++++++++------------
 cli_classic.c  |    2 +-
 flash.h        |    3 +++
 flashrom.c     |    4 ++++
 internal.c     |    2 +-
 layout.c       |   10 +++++-----
 programmer.h   |    2 --
 8 files changed, 24 insertions(+), 22 deletions(-)

diff --git a/board_enable.c b/board_enable.c
index 6c58e91..1da2775 100644
--- a/board_enable.c
+++ b/board_enable.c
@@ -2143,7 +2143,7 @@ static const struct board_pciid_enable *board_match_coreboot_name(
 	if (partmatch)
 		return partmatch;
 
-	if (!partvendor_from_cbtable) {
+	if (!g->partvendor_from_cbtable) {
 		/* Only warn if the mainboard type was not gathered from the
 		 * coreboot table. If it was, the coreboot implementor is
 		 * expected to fix flashrom, too.
diff --git a/cbtable.c b/cbtable.c
index a413e50..8a45af0 100644
--- a/cbtable.c
+++ b/cbtable.c
@@ -37,20 +37,17 @@ void sync_globals5(void)
 	g = get_globals();
 }
 
-char *lb_part = NULL, *lb_vendor = NULL;
-int partvendor_from_cbtable = 0;
-
 void lb_vendor_dev_from_string(char *boardstring)
 {
 	char *tempstr2 = NULL;
 	strtok(boardstring, ":");
 	tempstr2 = strtok(NULL, ":");
 	if (tempstr2) {
-		lb_vendor = boardstring;
-		lb_part = tempstr2;
+		g->lb_vendor = boardstring;
+		g->lb_part = tempstr2;
 	} else {
-		lb_vendor = NULL;
-		lb_part = boardstring;
+		g->lb_vendor = NULL;
+		g->lb_part = boardstring;
 	}
 }
 
@@ -169,12 +166,12 @@ static void find_mainboard(struct lb_record *ptr, unsigned long addr)
 	snprintf(part, 255, "%.*s", max_size - rec->part_number_idx,
 		 rec->strings + rec->part_number_idx);
 
-	if (lb_part) {
-		msg_pdbg("Overwritten by command line, vendor ID: %s, part ID: %s.\n", lb_vendor, lb_part);
+	if (g->lb_part) {
+		msg_pdbg("Overwritten by command line, vendor ID: %s, part ID: %s.\n", g->lb_vendor, g->lb_part);
 	} else {
-		partvendor_from_cbtable = 1;
-		lb_part = strdup(part);
-		lb_vendor = strdup(vendor);
+		g->partvendor_from_cbtable = 1;
+		g->lb_part = strdup(part);
+		g->lb_vendor = strdup(vendor);
 	}
 }
 
diff --git a/cli_classic.c b/cli_classic.c
index d82459a..e527778 100644
--- a/cli_classic.c
+++ b/cli_classic.c
@@ -339,7 +339,7 @@ int cli_classic(int argc, char *argv[])
 #endif
 
 #if CONFIG_INTERNAL == 1
-	if ((programmer != PROGRAMMER_INTERNAL) && (lb_part || lb_vendor)) {
+	if ((programmer != PROGRAMMER_INTERNAL) && (g->lb_part || g->lb_vendor)) {
 		fprintf(stderr, "Error: --mainboard requires the internal "
 				"programmer. Aborting.\n");
 		cli_classic_abort_usage();
diff --git a/flash.h b/flash.h
index fa595c4..b57f81e 100644
--- a/flash.h
+++ b/flash.h
@@ -281,6 +281,9 @@ struct globals {
 	enum chipbustype buses_supported;
 	int verbose;
 	char *chip_to_probe;
+
+	char *lb_part, *lb_vendor;
+	int partvendor_from_cbtable;
 };
 globals *get_globals(void);
 
diff --git a/flashrom.c b/flashrom.c
index 10f0351..c6cfefa 100644
--- a/flashrom.c
+++ b/flashrom.c
@@ -93,6 +93,10 @@ static void init_globals(void)
 {
 	g.verbose = 0;
 	g.chip_to_probe = NULL;
+
+	g.lb_part = NULL, g.lb_vendor = NULL;
+	g.partvendor_from_cbtable = 0;
+
 	sync_all_globals();
 }
 
diff --git a/internal.c b/internal.c
index e920811..028a0cb 100644
--- a/internal.c
+++ b/internal.c
@@ -284,7 +284,7 @@ int internal_init(void)
 	init_superio_ite();
 #endif
 
-	board_flash_enable(lb_vendor, lb_part);
+	board_flash_enable(g->lb_vendor, g->lb_part);
 
 	/* Even if chipset init returns an error code, we don't want to abort.
 	 * The error code might have been a warning only.
diff --git a/layout.c b/layout.c
index d387c3f..a91296c 100644
--- a/layout.c
+++ b/layout.c
@@ -109,7 +109,7 @@ int show_id(uint8_t *bios, int size, int force)
 	 * If lb_vendor is not set, the coreboot table was
 	 * not found. Nor was -m VENDOR:PART specified.
 	 */
-	if (!lb_vendor || !lb_part) {
+	if (!g->lb_vendor || !g->lb_part) {
 		msg_pinfo("Note: If the following flash access fails, "
 		       "try -m <vendor>:<mainboard>.\n");
 		return 0;
@@ -118,8 +118,8 @@ int show_id(uint8_t *bios, int size, int force)
 	/* These comparisons are case insensitive to make things
 	 * a little less user^Werror prone. 
 	 */
-	if (!strcasecmp(mainboard_vendor, lb_vendor) &&
-	    !strcasecmp(mainboard_part, lb_part)) {
+	if (!strcasecmp(mainboard_vendor, g->lb_vendor) &&
+	    !strcasecmp(mainboard_part, g->lb_part)) {
 		msg_pdbg("This firmware image matches this mainboard.\n");
 	} else {
 		if (force_boardmismatch) {
@@ -133,8 +133,8 @@ int show_id(uint8_t *bios, int size, int force)
 			       "that\nyou are using a correct "
 			       "image for this mainboard or override\nthe detected "
 			       "values with --mainboard <vendor>:<mainboard>.\n\n",
-			       mainboard_vendor, mainboard_part, lb_vendor,
-			       lb_part);
+			       mainboard_vendor, mainboard_part, g->lb_vendor,
+			       g->lb_part);
 			exit(1);
 		}
 	}
diff --git a/programmer.h b/programmer.h
index 6a28dbe..03fe007 100644
--- a/programmer.h
+++ b/programmer.h
@@ -268,8 +268,6 @@ void cleanup_cpu_msr(void);
 /* cbtable.c */
 void lb_vendor_dev_from_string(char *boardstring);
 int coreboot_init(void);
-extern char *lb_part, *lb_vendor;
-extern int partvendor_from_cbtable;
 
 /* dmi.c */
 extern int has_dmi_support;
-- 
1.7.6

